==> haskell-cpphs-1.20.8-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.8
id: cpphs-1.20.8-GyXkmDRyCCk1Z2EfyxKuOh
key: cpphs-1.20.8-GyXkmDRyCCk1Z2EfyxKuOh
license: LGPL
copyright: 2004-2017, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
abi: af11361355d802e7c7eb6aa76b806a47
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cpphs-1.20.8
library-dirs: /usr/lib/ghc-8.0.2/site-local/cpphs-1.20.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/cpphs-1.20.8
hs-libraries: HScpphs-1.20.8-GyXkmDRyCCk1Z2EfyxKuOh
depends:
    base-4.9.1.0 directory-1.3.0.0
    old-locale-1.0.0.7-KGBP1BSKxH5GCm0LnZP04j
    old-time-1.1.0.3-EZzkBJ4NQxX4hHavrKxgaT
    polyparse-1.12-2dxp3MdYSYOEcDgRo6TZWF
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cpphs-1.20.8-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.8
id: cpphs-1.20.8-7xqV6K11ztn3NWgQm6oXk8
key: cpphs-1.20.8-7xqV6K11ztn3NWgQm6oXk8
license: LGPL
copyright: 2004-2017, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
abi: 458f8d56625e11c2ee120946f1275641
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cpphs-1.20.8
library-dirs: /usr/lib/ghc-8.2.1/site-local/cpphs-1.20.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/cpphs-1.20.8
hs-libraries: HScpphs-1.20.8-7xqV6K11ztn3NWgQm6oXk8
depends:
    base-4.10.0.0 directory-1.3.0.2
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=e36378d40a60df0fd2f08fb5571aec27
             polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS=8180aaf9b1daa90854e0f351b4f90250
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
